# NVIDIA NIM - Generative AI Plugin

With this plugin, you can leverage LLMs from [NVIDIA NIMs](https://docs.nvidia.com/nim/large-language-models/latest/introduction.html).


# Capabilities

- Custom LLM connection for LLMs hosted in [NVIDIA](https://build.nvidia.com/explore/discover) Cloud or self-hosted NIM containers
- Connect to a deployed NVIDIA container chat completion endpoint to use in Dataiku Prompt Studios, LLM recipes, and via the LLM Mesh Python APIs
- Connect to a deployed NVIDIA container embedding endpoint to use in the Dataiku Embed recipe for Retrieval Augmented Generation (RAG)


# Limitations

- Must use Dataiku >= v13.0.0
- Must have setup an NVIDIA Authentication API Key
- Must deploy and maintain NVIDIA container models

## Setup access to NVIDIA NIM

- An NVIDIA AI Enterprise subscription is required to get access to NIM Models.
- With subscription you can access NVIDIA models via [NVIDIA Cloud](https://build.nvidia.com/explore/discover) or by using Docker containers from the NGC Catalog. Follow the steps [here](https://docs.nvidia.com/nim/large-language-models/latest/getting-started.html) to set up a NIM container.

## Setup the plugin in Dataiku

- Install the Plugin using the [installation guide](https://doc.dataiku.com/dss/latest/plugins/installing.html).
- Go to Plugins → Installed → NVIDIA NIM Plugin → Settings → Add Preset → Define a Preset Key.

![api key preset screenshot screenshot](../nvidia-nim-llm/assets/api-key-preset-screenshot.png?raw=true)

- Every user can set up the preset under their Dataiku profile → API Credentials → Credentials → Plugin credentials. Click the Edit icon and paste your NIM API key.

![credentials screenshot](../nvidia-nim-llm/assets/credentials-screenshot.png?raw=true)


## Setup the NIM Connection in Dataiku
- Go to Administration → Connections → New Connection → Custom LLM (LLM Mesh)

![new custom connection screenshot](../nvidia-nim-llm/assets/new-custom-connection-screenshot.png?raw=true)

- Provide a connection name and select NVIDIA NIM Connector in the Plugin dropdown

![custom nvidia connection screenshot](../nvidia-nim-llm/assets/custom-nvidia-connection.png?raw=true)

- To add models - Click Add Model
    - **Id**: Unique name to identify model
    - **Capability** : Chat Completion / Text Embedding
    - **Type**: NVIDIA NIM LLM Connector
    - **Keys Preset**: Select the preset name defined in the plugin setting
    - **Endpoint URL**: Provide complete URL (examples below)
        - For chat completion - https://hostname/v1/chat/completions
        - For chat completion - https://hostname/v1/retrieval/nvidia/embeddings
    - **Model Key**: Provide the model key accepted by NIM containers. E.g. 'google/gemma-2b' or 'NV-Embed-QA'
    - **Input Type** (This property only applied to Embedding models. By default, it is set to query): query or passage

Once the setup is complete, you can access NIM models both in LLM Powered Visual Recipes, Prompt Studios and using Python and REST LLM Mesh APIs.